%Comparison of # photons from blacbody radiator (P) vs D-illuminant, at the
%same illuminance.  illuminant function from optprop toolbox.  See:
%https://www.strollswithmydog.com/how-many-photons-on-pixel-at-given-exposure/
%V = CIE (2008) physiologically-relevant 2-deg V luminous efficiency function
%Results are slightly different in the article because an earlier V was used there

wl = 380:780;                               %nm, irradiance wl range
vis = 16:339;                               %'visible' range, 395:718nm
V = csvread('D:\A\Downloads\linCIE2008v2e_1.csv'); %from cvrl.org
V = [zeros(1,10) V(1:391,2)'];

h = 6.62607004e-34;                         %Planck's
c = 299792458;                              %speed of light in vacuum
k = 1.38064852e-23;                         %Boltzmann's
c1 = 2 * pi * h * c^2;                      %W.m^4/m^2
c2 = h * c / k;                             %m.K
Km = 683.002;                               %lm/W

T = 5300;                                   %deg K
M = c1 ./ (wl*10^-9).^5 ./ (exp(c2./(wl*10^-9)/T) -1) * 10^-9;  %W/m^2/m
illP = Km * M .* V;                         %bb illuminance, lm/m^2
D = illuminant(['D' num2str(T)], wl);       %relative, D-illuminant at given T
illD = Km * D .* V;                         %D-ill relative illuminance
D = D * sum(illP)/sum(illD);                %normalized to bb illuminance

phP = M .* (wl*10^-9) ./ h ./ c;            %photons/s/m^2/nm, bb
n_phP = sum(phP(vis))/sum(illP)/10^12;      %number of photons/lx-s/um^2
phD = D .* (wl*10^-9) ./ h ./ c;            %photons/s/m^2/nm, D-ill
n_phD = sum(phD(vis))/sum(illP)/10^12;      %number of photons/lx-s/um^2

disp(['# Photons/lx-s/um^2 at ' num2str(T) 'K - blackbody: '...
    num2str(round(n_phP)) ', D-illuminant: ' num2str(round(n_phD)) ', Ratio: '...
    num2str(n_phD/n_phP,4)])
figure; plot(wl,phP,wl,phD); grid; title('Same Illuminance')
xlabel('nm'); ylabel('photons/s/\mum^2/nm')
legend('Blackbody',['D' num2str(T)],'Location','NW')
